==> beast-payment-api-1.0.0-20180111.081520-60-sources.jar: com/thebeastshop/payment/vo/PKafkaTradeVO.java <==
package com.thebeastshop.payment.vo;

import java.math.BigDecimal;
import java.util.Date;

/**
 * @author gongjun[jun.gong@thebeastshop.com]
 * @since 2017-12-22 15:45
 */
public class PKafkaTradeVO {

    /**
     * 唯一标识
     */
    private Long id;
    /**
     * 支付流水号
     */
    private String tradeCode;
    /**
     * 外部流水号
     */
    private String outTradeCode;
    /**
     * 渠道号
     */
    private String channelCode;
    /**
     * 访问来源
     */
    private Integer accessWay;
    /**
     * 交易类型
     */
    private Integer transType;
    /**
     * 支付金额
     */
    private BigDecimal paymentAmount;
    /**
     * 支付渠道
     */
    private Integer paymentChannel;
    /**
     * 支付模式
     */
    private Integer paymentMode;
    /**
     * 支付请求文本
     */
    private String requestText;
    /**
     * 支付状态
     */
    private Integer status;
    /**
     * 第三方返回信息
     */
    private String responseText;
    /**
     * 错误码
     */
    private String errorCode;
    /**
     * 第三方支付流水号
     */
    private String thirdPartyTradeCode;
    /**
     * 第三方返回状态
     */
    private String thirdPartyRespStatus;
    /**
     * 第三方错误码
     */
    private String thirdPartyErrorCode;
    /**
     * 是否当前有效支付流水
     */
    private Integer current;
    /**
     * 创建时间
     */
    private Date createTime;
    /**
     * 回调时间
     */
    private Date returnTime;
    /**
     * 更新时间
     */
    private Date updateTime;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTradeCode() {
        return tradeCode;
    }

    public void setTradeCode(String tradeCode) {
        this.tradeCode = tradeCode;
    }

    public String getOutTradeCode() {
        return outTradeCode;
    }

    public void setOutTradeCode(String outTradeCode) {
        this.outTradeCode = outTradeCode;
    }

    public String getThirdPartyTradeCode() {
        return thirdPartyTradeCode;
    }

    public void setThirdPartyTradeCode(String thirdPartyTradeCode) {
        this.thirdPartyTradeCode = thirdPartyTradeCode;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public Integer getAccessWay() {
        return accessWay;
    }

    public void setAccessWay(Integer accessWay) {
        this.accessWay = accessWay;
    }

    public Integer getTransType() {
        return transType;
    }

    public void setTransType(Integer transType) {
        this.transType = transType;
    }

    public BigDecimal getPaymentAmount() {
        return paymentAmount;
    }

    public void setPaymentAmount(BigDecimal paymentAmount) {
        this.paymentAmount = paymentAmount;
    }

    public Integer getPaymentChannel() {
        return paymentChannel;
    }

    public void setPaymentChannel(Integer paymentChannel) {
        this.paymentChannel = paymentChannel;
    }

    public Integer getPaymentMode() {
        return paymentMode;
    }

    public void setPaymentMode(Integer paymentMode) {
        this.paymentMode = paymentMode;
    }

    public String getRequestText() {
        return requestText;
    }

    public void setRequestText(String requestText) {
        this.requestText = requestText;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getResponseText() {
        return responseText;
    }

    public void setResponseText(String responseText) {
        this.responseText = responseText;
    }

    public String getErrorCode() {
        return errorCode;
    }

    public void setErrorCode(String errorCode) {
        this.errorCode = errorCode;
    }


    public String getThirdPartyRespStatus() {
        return thirdPartyRespStatus;
    }

    public void setThirdPartyRespStatus(String thirdPartyRespStatus) {
        this.thirdPartyRespStatus = thirdPartyRespStatus;
    }

    public String getThirdPartyErrorCode() {
        return thirdPartyErrorCode;
    }

    public void setThirdPartyErrorCode(String thirdPartyErrorCode) {
        this.thirdPartyErrorCode = thirdPartyErrorCode;
    }

    public Integer getCurrent() {
        return current;
    }

    public void setCurrent(Integer current) {
        this.current = current;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getReturnTime() {
        return returnTime;
    }

    public void setReturnTime(Date returnTime) {
        this.returnTime = returnTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }
}

==> beast-payment-api-1.0.0-20180118.112020-68-sources.jar: com/thebeastshop/payment/vo/PKafkaTradeVO.java <==
package com.thebeastshop.payment.vo;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * @author gongjun[jun.gong@thebeastshop.com]
 * @since 2017-12-22 15:45
 */
public class PKafkaTradeVO implements PTrade, Serializable {

    /**
     * 唯一标识
     */
    private Long id;
    /**
     * 支付流水号
     */
    private String tradeCode;
    /**
     * 外部流水号
     */
    private String outTradeCode;
    /**
     * 渠道号
     */
    private String channelCode;
    /**
     * 访问来源
     */
    private Integer accessWay;
    /**
     * 交易类型
     */
    private Integer transType;
    /**
     * 支付金额
     */
    private BigDecimal paymentAmount;
    /**
     * 支付渠道
     */
    private Integer paymentChannel;
    /**
     * 支付模式
     */
    private Integer paymentMode;
    /**
     * 支付请求文本
     */
    private String requestText;
    /**
     * 支付状态
     */
    private Integer status;
    /**
     * 第三方返回信息
     */
    private String responseText;
    /**
     * 错误码
     */
    private String errorCode;
    /**
     * 第三方支付流水号
     */
    private String thirdPartyTradeCode;
    /**
     * 第三方返回状态
     */
    private String thirdPartyRespStatus;
    /**
     * 第三方错误码
     */
    private String thirdPartyErrorCode;
    /**
     * 创建时间
     */
    private Date createTime;
    /**
     * 回调时间
     */
    private Date returnTime;
    /**
     * 更新时间
     */
    private Date updateTime;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getTradeCode() {
        return tradeCode;
    }

    public void setTradeCode(String tradeCode) {
        this.tradeCode = tradeCode;
    }

    public String getOutTradeCode() {
        return outTradeCode;
    }

    public void setOutTradeCode(String outTradeCode) {
        this.outTradeCode = outTradeCode;
    }

    public String getThirdPartyTradeCode() {
        return thirdPartyTradeCode;
    }

    public void setThirdPartyTradeCode(String thirdPartyTradeCode) {
        this.thirdPartyTradeCode = thirdPartyTradeCode;
    }

    public String getChannelCode() {
        return channelCode;
    }

    public void setChannelCode(String channelCode) {
        this.channelCode = channelCode;
    }

    public Integer getAccessWay() {
        return accessWay;
    }

    public void setAccessWay(Integer accessWay) {
        this.accessWay = accessWay;
    }

    public Integer getTransType() {
        return transType;
    }

    public void setTransType(Integer transType) {
        this.transType = transType;
    }

    public BigDecimal getPaymentAmount() {
        return paymentAmount;
    }

    public void setPaymentAmount(BigDecimal paymentAmount) {
        this.paymentAmount = paymentAmount;
    }

    public Integer getPaymentChannel() {
        return paymentChannel;
    }

    public void setPaymentChannel(Integer paymentChannel) {
        this.paymentChannel = paymentChannel;
    }

    public Integer getPaymentMode() {
        return paymentMode;
    }

    public void setPaymentMode(Integer paymentMode) {
        this.paymentMode = paymentMode;
    }

    public String getRequestText() {
        return requestText;
    }

    public void setRequestText(String requestText) {
        this.requestText = requestText;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getResponseText() {
        return responseText;
    }

    public void setResponseText(String responseText) {
        this.responseText = responseText;
    }

    public String getErrorCode() {
        return errorCode;
    }

    public void setErrorCode(String errorCode) {
        this.errorCode = errorCode;
    }


    public String getThirdPartyRespStatus() {
        return thirdPartyRespStatus;
    }

    public void setThirdPartyRespStatus(String thirdPartyRespStatus) {
        this.thirdPartyRespStatus = thirdPartyRespStatus;
    }

    public String getThirdPartyErrorCode() {
        return thirdPartyErrorCode;
    }

    public void setThirdPartyErrorCode(String thirdPartyErrorCode) {
        this.thirdPartyErrorCode = thirdPartyErrorCode;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getReturnTime() {
        return returnTime;
    }

    public void setReturnTime(Date returnTime) {
        this.returnTime = returnTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }
}
